@@ -1,7 +1,7 @@
 package App::genpw;
 
 our $DATE = '2018-05-01'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,13 +142,14 @@ sub _pattern_has_w_conversion {
 
 $SPEC{genpw} = {
     v => 1.1,
-    summary => 'Generate random password',
+    summary => 'Generate random password (support patterns + wordlists)',
     description => <<'_',
 
 This is yet another utility to generate random password. Features:
 
 * Allow specifying pattern(s), e.g. '%8a%s' means 8 random alphanumeric
   characters followed by a symbol.
+* Use words from wordlists.
 * Use strong random source (<pm:Math::Random::Secure>) when available, otherwise
   fallback to Perl's builtin `rand()`.
 
@@ -291,7 +292,7 @@ sub genpw {
 }
 
 1;
-# ABSTRACT: Generate random password
+# ABSTRACT: Generate random password (support patterns + wordlists)
 
 __END__
 
@@ -301,11 +302,11 @@ __END__
 
 =head1 NAME
 
-App::genpw - Generate random password
+App::genpw - Generate random password (support patterns + wordlists)
 
 =head1 VERSION
 
-This document describes version 0.006 of App::genpw (from Perl distribution App-genpw), released on 2018-05-01.
+This document describes version 0.007 of App::genpw (from Perl distribution App-genpw), released on 2018-05-01.
 
 =head1 SYNOPSIS
 
@@ -320,7 +321,7 @@ Usage:
 
  genpw(%args) -> [status, msg, result, meta]
 
-Generate random password.
+Generate random password (support patterns + wordlists).
 
 This is yet another utility to generate random password. Features:
 
@@ -329,6 +330,8 @@ This is yet another utility to generate random password. Features:
 =item * Allow specifying pattern(s), e.g. '%8a%s' means 8 random alphanumeric
 characters followed by a symbol.
 
+=item * Use words from wordlists.
+
 =item * Use strong random source (L<Math::Random::Secure>) when available, otherwise
 fallback to Perl's builtin C<rand()>.
 
